@@ -160,7 +160,7 @@ class ThermoBuilder(Builder):
         )
         pd_entries = []
         for entry in entries:
-            material_entries[entry.entry_id][entry.data["run_type"]] = entry
+            material_entries[entry.data["material_id"]][entry.data["run_type"]] = entry
 
         if self.compatibility:
             with warnings.catch_warnings():
@@ -174,9 +174,10 @@ class ThermoBuilder(Builder):
 
         try:
             docs, pd = ThermoDoc.from_entries(pd_entries, deprecated=False)
-            for doc in docs:
-                doc.entries = material_entries[doc.material_id]
-                doc.entry_types = list(material_entries[doc.material_id].keys())
+
+            # for doc in docs:
+            #     doc.entries = material_entries[doc.material_id]
+            #     doc.entry_types = list(material_entries[doc.material_id].keys())
 
             pd_data = None
 
@@ -301,16 +302,17 @@ class ThermoBuilder(Builder):
             f"Got {len(materials_docs)} entries from DB for {len(query_chemsys)} sub-chemsys for {chemsys}"
         )
 
-        # Convert entries into ComputedEntries and store
+        # Convert GGA, GGA+U, R2SCAN entries into ComputedEntries and store
         for doc in materials_docs:
             for r_type, entry_dict in doc.get("entries", {}).items():
-                entry_dict["data"]["oxidation_states"] = oxi_states_data.get(
-                    entry_dict["entry_id"], {}
-                )
-                entry_dict["data"]["run_type"] = r_type
-                elsyms = sorted(set([el for el in entry_dict["composition"]]))
-                self._entries_cache["-".join(elsyms)].append(entry_dict)
-                all_entries.append(entry_dict)
+                if r_type in ["GGA", "GGA+U", "R2SCAN"]:
+                    entry_dict["data"]["oxidation_states"] = oxi_states_data.get(
+                        entry_dict["data"]["material_id"], {}
+                    )
+                    entry_dict["data"]["run_type"] = r_type
+                    elsyms = sorted(set([el for el in entry_dict["composition"]]))
+                    self._entries_cache["-".join(elsyms)].append(entry_dict)
+                    all_entries.append(entry_dict)
 
         self.logger.info(f"Total entries in {chemsys} : {len(all_entries)}")
 
